# Welcome to eaRthkIt climate's documentation!

Statistical analysis tools for meteorological and climate data..

```{toctree}
:caption: 'Contents:'
:maxdepth: 2

API Reference <_api/earthkit-climate/index>
```

# Indices and tables

- {ref}`genindex`
- {ref}`modindex`
- {ref}`search`
